@@ -7,12 +7,11 @@ package Class::Autouse::Parent;
 use strict;
 use Class::Autouse ();
 
-our $VERSION;
+use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.99_04';
+	$VERSION = '1.0';
 }
 
-# Anti-loop protection.
 # Maintain flags for "is the class in the process of loading"
 my %LOADING = ();
 
@@ -25,11 +24,11 @@ sub import {
 	return 1 if $LOADING{$parent};
 
 	# Autoload in our children
-	$LOADING{$parent} = 1;
-	Class::Autouse->autouse_recursive($parent);
-	delete $LOADING{$parent};
+	$LOADING{parent} = 1;
+	Class::Autouse->autouse_recursive( $parent );
+	delete $LOADING{parent};
 
-	return 1;
+	1;
 }
 
 1;
